/** 
 *******************************************************************************
 * @file    main.c
 * @brief   the application functions of UART0 to HyperTerminal demo for the 
 *          TOSHIBA 'TMPM332' Device Series 
 * @version V1.201
 * @date    2014/05/20
 * 
 * DO NOT USE THIS SOFTWARE WITHOUT THE SOFTWARE LICENSE AGREEMENT.
 * 
 * (C)Copyright TOSHIBA ELECTRONIC DEVICES & STORAGE CORPORATION 2017 All rights reserved
 *******************************************************************************
 */

#include "tmpm332_uart.h"

#define BufSize (sizeof(TxBuffer) / sizeof(*(TxBuffer)))

uint8_t TxBuffer[] = "TMPM332";
const uint8_t NumToBeTx = BufSize - 1U;
uint8_t TxCounter = 0U;
UART_InitTypeDef myUART;

void SIO_Configuration(TSB_SC_TypeDef * SCx);

int main(void)
{
    SIO_Configuration(UART0);

    myUART.BaudRate = 115200U;
    myUART.DataBits = UART_DATA_BITS_8;
    myUART.StopBits = UART_STOP_BITS_1;
    myUART.Parity = UART_NO_PARITY;
    myUART.Mode = UART_ENABLE_RX | UART_ENABLE_TX;
    myUART.FlowCtrl = UART_NONE_FLOW_CTRL;

    UART_Enable(UART0);
    UART_Init(UART0, &myUART);

    NVIC_EnableIRQ(INTTX0_IRQn);

    UART_SetTxData(UART0, (uint32_t) (TxBuffer[TxCounter++]));

    while (1) {
        /* Do nothing */
    }
}

void SIO_Configuration(TSB_SC_TypeDef * SCx)
{
    if (SCx == UART0) {
        TSB_PE_CR_PE0C = 1U;
        TSB_PE_FR1_PE0F1 = 1U;
        TSB_PE_FR1_PE1F1 = 1U;
        TSB_PE_IE_PE1IE = 1U;
    } else if (SCx == UART1) {
        TSB_PE_CR_PE4C = 1U;
        TSB_PE_FR1_PE4F1 = 1U;
        TSB_PE_FR1_PE5F1 = 1U;
        TSB_PE_IE_PE5IE = 1U;
    } else {
        /* Do nothing */
    }
}

#ifdef DEBUG
void assert_failed(char *file, int32_t line)
{
    while (1) {
       __NOP();
    }
}
#endif
